@@ -5,3 +5,5 @@ export * from './dataframe';
 export * from './transformations';
 export * from './datetime';
 export * from './text';
+export * from './valueFormats';
+export * from './field';
