@@ -1,5 +1,5 @@
 import { DisplayValue } from './displayValue';
-
+import { Field } from './dataFrame';
 export interface YAxis {
   index: number;
   min?: number;
@@ -16,6 +16,12 @@ export interface GraphSeriesXY {
   info?: DisplayValue[]; // Legend info
   isVisible: boolean;
   yAxis: YAxis;
+  // Field with series' time values
+  timeField: Field;
+  // Field with series' values
+  valueField: Field;
+  seriesIndex: number;
+  timeStep: number;
 }
 
 export interface CreatePlotOverlay {
