@@ -6,5 +6,8 @@ export * from './labels';
 export * from './labels';
 export * from './object';
 export * from './thresholds';
+export * from './namedColorsPalette';
+export * from './series';
 
 export { getMappedValue } from './valueMappings';
+export { getFlotPairs, getFlotPairsConstant } from './flotPairs';
