@@ -6,6 +6,8 @@ import (
 )
 
 var ErrInvalidApiKey = errors.New("Invalid API Key")
+var ErrInvalidApiKeyExpiration = errors.New("Negative value for SecondsToLive")
+var ErrDuplicateApiKey = errors.New("API Key Organization ID And Name Must Be Unique")
 
 type ApiKey struct {
 	Id      int64
@@ -15,15 +17,17 @@ type ApiKey struct {
 	Role    RoleType
 	Created time.Time
 	Updated time.Time
+	Expires *int64
 }
 
 // ---------------------
 // COMMANDS
 type AddApiKeyCommand struct {
-	Name  string   `json:"name" binding:"Required"`
-	Role  RoleType `json:"role" binding:"Required"`
-	OrgId int64    `json:"-"`
-	Key   string   `json:"-"`
+	Name          string   `json:"name" binding:"Required"`
+	Role          RoleType `json:"role" binding:"Required"`
+	OrgId         int64    `json:"-"`
+	Key           string   `json:"-"`
+	SecondsToLive int64    `json:"secondsToLive"`
 
 	Result *ApiKey `json:"-"`
 }
@@ -45,8 +49,9 @@ type DeleteApiKeyCommand struct {
 // QUERIES
 
 type GetApiKeysQuery struct {
-	OrgId  int64
-	Result []*ApiKey
+	OrgId          int64
+	IncludeInvalid bool
+	Result         []*ApiKey
 }
 
 type GetApiKeyByNameQuery struct {
@@ -64,7 +69,8 @@ type GetApiKeyByIdQuery struct {
 // DTO & Projections
 
 type ApiKeyDTO struct {
-	Id   int64    `json:"id"`
-	Name string   `json:"name"`
-	Role RoleType `json:"role"`
+	Id         int64      `json:"id"`
+	Name       string     `json:"name"`
+	Role       RoleType   `json:"role"`
+	Expiration *time.Time `json:"expiration,omitempty"`
 }
