@@ -1,4 +1,7 @@
 import LokiDatasource from './datasource';
+import { DataSourceSettings } from '@grafana/data';
+import { LokiOptions } from './types';
+import { createDatasourceSettings } from '../../../features/datasources/mocks';
 
 export function makeMockLokiDatasource(labelsAndValues: { [label: string]: string[] }): LokiDatasource {
   const labels = Object.keys(labelsAndValues);
@@ -25,3 +28,9 @@ export function makeMockLokiDatasource(labelsAndValues: { [label: string]: strin
     },
   } as any;
 }
+
+export function createDefaultConfigOptions(): DataSourceSettings<LokiOptions> {
+  return createDatasourceSettings<LokiOptions>({
+    maxLines: '531',
+  });
+}
