@@ -1,5 +1,4 @@
-import { DataQuery, DataSourceJsonData } from '@grafana/ui';
-import { Labels } from '@grafana/data';
+import { Labels, DataQuery, DataSourceJsonData } from '@grafana/data';
 
 export interface LokiQuery extends DataQuery {
   expr: string;
@@ -10,6 +9,7 @@ export interface LokiQuery extends DataQuery {
 
 export interface LokiOptions extends DataSourceJsonData {
   maxLines?: string;
+  derivedFields?: DerivedFieldConfig[];
 }
 
 export interface LokiResponse {
@@ -35,3 +35,9 @@ export interface LokiExpression {
   regexp: string;
   query: string;
 }
+
+export type DerivedFieldConfig = {
+  matcherRegex: string;
+  name: string;
+  url?: string;
+};
