@@ -6,7 +6,6 @@ module.exports = function(grunt) {
   grunt.registerTask('default', [
     'clean:build',
     'phantomjs',
-    'webpack:dev'
   ]);
 
   // prettier-ignore
@@ -31,19 +30,11 @@ module.exports = function(grunt) {
     'newer:exec:typecheckRoot'
   ]);
 
-  // prettier-ignore
-  grunt.registerTask('precommit', [
-    'newer:sasslint',
-    'typecheck',
-    'tslint',
-    'no-only-tests',
-    'no-focus-convey-tests'
-  ]);
-
   grunt.registerTask('no-only-tests', function() {
     var files = grunt.file.expand(
       'public/**/*@(_specs|.test).@(ts|js|tsx|jsx)',
-      'packages/grafana-ui/**/*@(_specs|.test).@(ts|js|tsx|jsx)'
+      'packages/grafana-data/**/*@(_specs|.test).@(ts|js|tsx|jsx)',
+      'packages/**/*@(_specs|.test).@(ts|js|tsx|jsx)'
     );
     grepFiles(files, '.only(', 'found only statement in test: ');
   });
@@ -65,4 +56,3 @@ module.exports = function(grunt) {
     });
   }
 };
-
